;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "sideline" "20260101.540"
  "Show information on the side."
  '((emacs "28.1")
    (ht    "2.4"))
  :url "https://github.com/emacs-sideline/sideline"
  :commit "b4ada1ddf7da96c2e87453130f6ff7b7d577810f"
  :revdesc "b4ada1ddf7da"
  :keywords '("convenience")
  :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
  :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
